..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Ipython Console Example
===============================================================================

An example of the ``IPythonConsole`` widget.

Requires qtconsole to be installed.

.. TIP:: To see this example in action, download it from
 :download:`ipython_console <../../../examples/widgets/ipython_console.enaml>`
 and run::

   $ enaml-run ipython_console.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_ipython_console.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/widgets/ipython_console.enaml
    :language: enaml
